MCPcopy Create free account
hub / github.com/ROCm/rocPRIM / increment

Function increment

test/hipgraph/test_hipgraph_basic.cpp:40–45  ·  view source on GitHub ↗

Source from the content-addressed store, hash-verified

38
39// Simple test kernel that increments a value using a single thread.
40__global__ __launch_bounds__(ROCPRIM_DEFAULT_MAX_BLOCK_SIZE) void increment(int* data)
41{
42 const int gid = blockIdx.x * blockDim.x + threadIdx.x;
43 if (!gid)
44 data[gid]++;
45}
46
47// Another simple kernel that can be used to test atomics inside a graph.
48__global__ __launch_bounds__(ROCPRIM_DEFAULT_MAX_BLOCK_SIZE) void atomicIncrement(int* data)

Callers

nothing calls this directly

Calls

no outgoing calls

Tested by

no test coverage detected